<?php
/**
 * Common functions class
 *
 * @package MultiPOS - Point of Sale for WooCommerce
 * @version 1.0.0
 */

namespace DDWCMultiPOS\Includes\Common;

use DDWCMultiPOS\Includes\Common\DDWCPOS_Email_Notification_Handler;
use DDWCMultiPOS\Helper\Outlet\DDWCPOS_Outlet_Helper;

defined( 'ABSPATH' ) || exit();

if ( ! class_exists( 'DDWCPOS_Common_Functions' ) ) {
	/**
	 * Common functions
	 */
	class DDWCPOS_Common_Functions {
		/**
		 * Configuration Variable
		 *
		 * @var array
		 */
		protected $ddwcpos_configuration;

		/**
		 * Construct
		 */
		public function __construct( $ddwcpos_configuration ) {
			$this->ddwcpos_configuration = $ddwcpos_configuration;
		}

		/**
		 * Init function
		 *
		 * @return void
		 */
		public function ddwcpos_init() {
			add_rewrite_endpoint( $this->ddwcpos_configuration[ 'endpoint' ], EP_ROOT | EP_PAGES );
			add_rewrite_endpoint( $this->ddwcpos_configuration[ 'kitchen_endpoint' ], EP_ROOT | EP_PAGES );
		}

		/**
		 * WooCommerce refund created function
		 *
		 * @param int $order_id
		 * @param int $refund_id
		 * @return void
		 */
		public function ddwcpos_woocommerce_refund_created( $refund_id, $refund_args ) {
			if ( $refund_args[ 'restock_items' ] ) {
				$order_id       = $refund_args[ 'order_id' ];
				$outlet_id      = get_post_meta( $order_id, '_ddwcpos_outlet_id', true );
				$outlet_helper  = new DDWCPOS_Outlet_Helper();
				$inventory_type = $outlet_helper->ddwcpos_get_inventory_type( $outlet_id );

				if ( ! empty( $outlet_id ) && 'custom' === $inventory_type ) {
					$line_items = $refund_args[ 'line_items' ];

					foreach ( $line_items as $item_id => $line_item ) {
						$order_item      = new \WC_Order_Item_Product( $item_id );
						$order_item_data = $order_item->get_data();
						$product_id      = ! empty( $order_item_data[ 'variation_id' ] ) ? $order_item_data[ 'variation_id' ] : $order_item_data[ 'product_id' ];
						$custom_stock    = intval( get_post_meta( $product_id, '_ddwcpos_outlet_stock_' . $outlet_id, true ) );

						update_post_meta( $product_id, '_ddwcpos_outlet_stock_' . $outlet_id, $custom_stock + $line_item[ 'qty' ] );

						$product       = wc_get_product( $product_id );
						$product_stock = $product->get_stock_quantity();

						wc_update_product_stock( $product, $product_stock - $line_item[ 'qty' ] );
					}
				}
			}
		}
	}
}
