<?php
/**
 * @author DevDiggers
 * @version 1.0.0
 * This file handles all front end action callbacks.
 */

namespace DDWCMultiPOS\Includes\Front;

use DDWCMultiPOS\Templates\Front\POS\DDWCPOS_Layout;
use DDWCMultiPOS\Templates\Front\Kitchen\DDWCPOS_Kitchen_Layout;
use DDWCMultiPOS\Helper\Outlet\DDWCPOS_Outlet_Helper;
use DDWCMultiPOS\Helper\Invoice\DDWCPOS_Invoice_Helper;

defined( 'ABSPATH' ) || exit();

if ( ! class_exists( 'DDWCPOS_Front_Functions' ) ) {    
    /**
     * Front functions class
     */
    class DDWCPOS_Front_Functions {
        /**
         * Configuration Variable
         *
         * @var array
         */
        protected $ddwcpos_configuration;

        /**
         * Construct
         */
        public function __construct( $ddwcpos_configuration ) {
            $this->ddwcpos_configuration = $ddwcpos_configuration;
        }

        /**
		 * Add Query Vars function
		 *
		 * @param array $vars
		 * @return array
		 */
		public function ddwcpos_add_query_vars( $vars ) {
			$vars[] = $this->ddwcpos_configuration[ 'endpoint' ];
			$vars[] = $this->ddwcpos_configuration[ 'kitchen_endpoint' ];
            return $vars;
		}

        /**
         * Parse request function
         *
         * @return void
         */
        public function ddwcpos_parse_request( $wp ) {
            if ( array_key_exists( $this->ddwcpos_configuration[ 'endpoint' ], $wp->query_vars ) ) {
                new DDWCPOS_Layout( $this->ddwcpos_configuration );
                exit();
            }
            if ( array_key_exists( $this->ddwcpos_configuration[ 'kitchen_endpoint' ], $wp->query_vars ) ) {
                new DDWCPOS_Kitchen_Layout( $this->ddwcpos_configuration );
                exit();
            }
        }

        /**
         * WP loaded function
         *
         * @return void
         */
        public function ddwcpos_wp_loaded() {
            if ( is_user_logged_in() && preg_match( "/\b\/{$this->ddwcpos_configuration[ 'endpoint' ]}\b/", $_SERVER[ 'REQUEST_URI' ] ) ) {
                $user = wp_get_current_user();
                if ( ! ( in_array( 'ddwcpos_cashier', $user->roles, true ) || in_array( 'administrator', $user->roles, true ) || in_array( 'shop_manager', $user->roles, true ) || apply_filters( 'ddwcpos_allow_administrator_access_for_pos_to_user', false ) ) ) {
                    wp_safe_redirect( get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) );
                    exit();
                }
            }
        }

		/**
		 * Login failed function
		 *
		 * @param object $user
		 * @return void
		 */
		public function ddwcpos_login_failed( $user ) {
			// check what page the login attempt is coming from
			$referrer = ! empty( $_SERVER[ 'HTTP_REFERER' ] ) ? $_SERVER[ 'HTTP_REFERER' ] : '';

			$error = false;

			if ( empty( $_POST[ 'log' ] ) || empty( $_POST[ 'pwd' ] ) ) {
				$error = true;
			}

			if ( strstr( $referrer, '/' . $this->ddwcpos_configuration[ 'endpoint' ] ) !== false && ( $user !== null || $error ) ) {
				$url = site_url( $this->ddwcpos_configuration[ 'endpoint' ] );
				// make sure we don't already have a failed login attempt
				if ( ! strstr( $referrer, '?login=failed' ) ) {
					// Redirect to the login page and append a querystring of login failed
					wp_redirect( $url . '?login=failed' );
				} else {
					wp_redirect( $url );
				}

				exit();
			}
		}

		/**
		 * Stop mails at pos end function
		 *
		 * @param object $order
		 * @return void
		 */
		public function ddwcpos_stop_mails_at_pos_end( $order ) {
			if ( empty( $this->ddwcpos_configuration[ 'order_mails_enabled' ] ) && ! empty( get_post_meta( $order->get_id(), '_ddwcpos_outlet_id', true ) ) ) {
				remove_action( 'woocommerce_order_status_pending_to_processing_notification', [ WC()->mailer()->emails[ 'WC_Email_New_Order' ], 'trigger' ] );
				remove_action( 'woocommerce_order_status_pending_to_completed_notification', [ WC()->mailer()->emails[ 'WC_Email_New_Order' ], 'trigger' ] );
				remove_action( 'woocommerce_order_status_pending_to_on-hold_notification', [ WC()->mailer()->emails[ 'WC_Email_New_Order' ], 'trigger' ] );
				remove_action( 'woocommerce_order_status_failed_to_processing_notification', [ WC()->mailer()->emails[ 'WC_Email_New_Order' ], 'trigger' ] );
				remove_action( 'woocommerce_order_status_failed_to_completed_notification', [ WC()->mailer()->emails[ 'WC_Email_New_Order' ], 'trigger' ] );
				remove_action( 'woocommerce_order_status_failed_to_on-hold_notification', [ WC()->mailer()->emails[ 'WC_Email_New_Order' ], 'trigger' ] );
				remove_action( 'woocommerce_order_status_cancelled_to_processing_notification', [ WC()->mailer()->emails[ 'WC_Email_New_Order' ], 'trigger' ] );
				remove_action( 'woocommerce_order_status_cancelled_to_completed_notification', [ WC()->mailer()->emails[ 'WC_Email_New_Order' ], 'trigger' ] );
				remove_action( 'woocommerce_order_status_cancelled_to_on-hold_notification', [ WC()->mailer()->emails[ 'WC_Email_New_Order' ], 'trigger' ] );

				remove_action( 'woocommerce_order_status_pending_to_processing_notification', [ WC()->mailer()->emails[ 'WC_Email_Customer_Processing_Order' ], 'trigger' ] );
				remove_action( 'woocommerce_order_status_completed_notification', [ WC()->mailer()->emails[ 'WC_Email_Customer_Completed_Order' ], 'trigger' ] );
			}
		}

		/**
		 * Front scripts enqueue function
		 *
		 * @return void
		 */
		public function ddwcpos_front_scripts() {
			global $wp;
			if ( array_key_exists( $this->ddwcpos_configuration[ 'endpoint' ], $wp->query_vars ) ) {
				wp_enqueue_style( 'ddwcpos-login-style', DDWCPOS_PLUGIN_URL . 'assets/css/login.css', [], DDWCPOS_SCRIPT_VERSION );

				wp_enqueue_script( 'ddwcpos-login-script', DDWCPOS_PLUGIN_URL . 'assets/js/login.js', [], DDWCPOS_SCRIPT_VERSION );

				wp_localize_script(
					'ddwcpos-login-script',
					'ddwcposLoginObj',
					[
						'siteUrl'        => esc_url( site_url() ),
						'networkSiteUrl' => esc_url( network_site_url() ),
					]
				);

				if ( is_user_logged_in() ) {
					$dependencies = apply_filters( 'ddwcpos_modify_pos_script_dependencies', [ 'wp-element' ] );

					wp_enqueue_style( 'ddwcpos-pos-style', DDWCPOS_PLUGIN_URL . 'assets/css/pos.css', [], DDWCPOS_SCRIPT_VERSION );
					wp_enqueue_script( 'ddwcpos-pos-script', DDWCPOS_PLUGIN_URL . 'assets/js/pos.js', $dependencies, DDWCPOS_SCRIPT_VERSION );

					wp_set_script_translations( 'ddwcpos-pos-script', 'ddwc-multipos' );

					$ddwcpos_configuration = $this->ddwcpos_configuration;
					$user                  = wp_get_current_user();
					$tax_display_cart      = get_option( 'woocommerce_tax_display_cart' );
					$outlet_helper         = new DDWCPOS_Outlet_Helper();
					$invoice_helper        = new DDWCPOS_Invoice_Helper( $this->ddwcpos_configuration );
					$site_url              = site_url();

					$user_data = (array) $user->data;

					$user_data[ 'first_name' ] = $user->first_name;
					$user_data[ 'last_name' ]  = $user->last_name;

					if ( in_array( 'ddwcpos_cashier', $user->roles, true ) ) {
						$assigned_outlets = get_user_meta( $user->ID, '_ddwcpos_assigned_outlets', true );
						$assigned_outlets = $outlet_helper->ddwcpos_get_outlet_details_by_ids( ! empty( $assigned_outlets ) ? $assigned_outlets : [] );
					} else if ( in_array( 'administrator', $user->roles, true ) || in_array( 'shop_manager', $user->roles, true ) || apply_filters( 'ddwcpos_allow_administrator_access_for_pos_to_user', false ) ) {
						$assigned_outlets = $outlet_helper->ddwcpos_get_all_outlets( 999999, 0, '' );
					}

					if ( 'excl' !== $tax_display_cart ) {
						$tax_label = ' <small class="tax_label">' . WC()->countries->inc_tax_or_vat() . '</small>';
					} else {
						$tax_label = ' <small class="tax_label">' . WC()->countries->ex_tax_or_vat() . '</small>';
					}

					$order_status = wc_get_order_statuses();

					$ddwcpos_configuration[ 'tax_included_label' ]  = WC()->countries->inc_tax_or_vat();
					$ddwcpos_configuration[ 'tax_label' ]           = $tax_label;
					$ddwcpos_configuration[ 'current_date' ]        = current_time( 'Y-m-d' );
					$ddwcpos_configuration[ 'per_page' ]            = 200;
					$ddwcpos_configuration[ 'invoice_html' ]        = $invoice_helper->ddwcpos_get_invoice_html();
					$ddwcpos_configuration[ 'invoice_css' ]         = $invoice_helper->ddwcpos_get_invoice_css();
					$ddwcpos_configuration[ 'placeholder_image' ]   = wc_placeholder_img_src();
					$ddwcpos_configuration[ 'language_attributes' ] = get_language_attributes( 'html' );
					$ddwcpos_configuration[ 'order_status_label' ]  = $order_status[ $ddwcpos_configuration[ 'order_status' ] ];
					$ddwcpos_configuration[ 'logo_url' ]            = ! empty( $ddwcpos_configuration[ 'logo' ] ) ? wp_get_attachment_url( $ddwcpos_configuration[ 'logo' ] ) : DDWCPOS_PLUGIN_URL . 'assets/images/logo.png';

					$api = [
						'GET_PRODUCTS_ENDPOINT'            => $site_url . '/wp-json/ddwcpos/v1/get-products',
						'GET_CATEGORIES_ENDPOINT'          => $site_url . '/wp-json/ddwcpos/v1/get-product-categories',
						'GET_CUSTOMERS_ENDPOINT'           => $site_url . '/wp-json/ddwcpos/v1/get-customers',
						'GET_COUNTRIES_STATES_ENDPOINT'    => $site_url . '/wp-json/ddwcpos/v1/get-countries-states',
						'CHECK_COUPON_ENDPOINT'            => $site_url . '/wp-json/ddwcpos/v1/check-coupon',
						'CHECK_CENTRALIZED_STOCK_ENDPOINT' => $site_url . '/wp-json/ddwcpos/v1/check-centralized-stock',
						'MANAGE_CUSTOMER_ENDPOINT'         => $site_url . '/wp-json/ddwcpos/v1/manage-customer',
						'DELETE_CUSTOMER_ENDPOINT'         => $site_url . '/wp-json/ddwcpos/v1/delete-customer',
						'CREATE_REFUND_ENDPOINT'           => $site_url . '/wp-json/ddwcpos/v1/create-refund',
						'CREATE_ORDER_ENDPOINT'            => $site_url . '/wp-json/ddwcpos/v1/create-order',
						'GET_ORDERS_ENDPOINT'              => $site_url . '/wp-json/ddwcpos/v1/get-orders',
						'SAVE_CASHIER_ENDPOINT'            => $site_url . '/wp-json/ddwcpos/v1/save-cashier',
						'GET_TRANSACTIONS_ENDPOINT'        => $site_url . '/wp-json/ddwcpos/v1/get-transactions',
						'CREATE_TRANSACTION_ENDPOINT'      => $site_url . '/wp-json/ddwcpos/v1/create-transaction',
						'MANAGE_KITCHEN_ORDERS_ENDPOINT'   => $site_url . '/wp-json/ddwcpos/v1/manage-kitchen-orders',
					];

					$parsed_url = parse_url( $site_url, PHP_URL_PATH );

					wp_localize_script(
						'ddwcpos-pos-script',
						'ddwcposPOSObj',
						[
							'ajax'                         => [
								'ajaxUrl'   => admin_url( 'admin-ajax.php' ),
								'ajaxNonce' => wp_create_nonce( 'ddwcpos-nonce' ),
							],
							'site_url'                     => $site_url,
							'siteUrl'                      => $parsed_url ? $parsed_url : '',
							'assignedOutlets'              => ! empty( $assigned_outlets ) ? $assigned_outlets : [],
							'ddwcpos_configuration'        => $ddwcpos_configuration,
							'user'                         => $user_data,
							'API'                          => $api,
							'currency_format_num_decimals' => esc_attr( wc_get_price_decimals() ),
							'currency_format_symbol'       => get_woocommerce_currency_symbol(),
							'currency_code'                => get_woocommerce_currency(),
							'currency_format_decimal_sep'  => esc_attr( wc_get_price_decimal_separator() ),
							'currency_format_thousand_sep' => esc_attr( wc_get_price_thousand_separator() ),
							'currency_format'              => esc_attr( str_replace( [ '%1$s', '%2$s' ], [ '%s', '%v' ], get_woocommerce_price_format() ) ),
							'logout_url'                   => wp_logout_url( site_url( $ddwcpos_configuration[ 'endpoint' ] ) ),
							'tax_enabled'                  => get_option( 'woocommerce_calc_taxes' ),
							'tax_type'                     => get_option( 'woocommerce_prices_include_tax' ),
							'tax_display_cart'             => $tax_display_cart,
							'weight_unit'                  => get_option( 'woocommerce_weight_unit' ),
							'current_date'                 => apply_filters( 'ddwcpos_modify_current_date_for_pos_transactions', current_time( 'Y-m-d' ) ),
							'plugin_url'                   => DDWCPOS_PLUGIN_URL,
							'plugin_file'                  => DDWCPOS_PLUGIN_FILE,
						]
					);
				}
			} else if ( array_key_exists( $this->ddwcpos_configuration[ 'kitchen_endpoint' ], $wp->query_vars ) ) {
				wp_enqueue_style( 'ddwcpos-login-style', DDWCPOS_PLUGIN_URL . 'assets/css/login.css', [], DDWCPOS_SCRIPT_VERSION );
				wp_enqueue_style( 'ddwcpos-kitchen-style', DDWCPOS_PLUGIN_URL . 'assets/css/kitchen.css', [], DDWCPOS_SCRIPT_VERSION );
				wp_enqueue_script( 'ddwcpos-kitchen-script', DDWCPOS_PLUGIN_URL . 'assets/js/kitchen.js', [ 'wp-element' ], DDWCPOS_SCRIPT_VERSION );

				wp_set_script_translations( 'ddwcpos-kitchen-script', 'ddwc-multipos' );

				$site_url              = site_url();
				$ddwcpos_configuration = $this->ddwcpos_configuration;

				$ddwcpos_configuration[ 'placeholder_image' ] = wc_placeholder_img_src();

				$api = [
					'MANAGE_KITCHEN_ORDERS_ENDPOINT' => $site_url . '/wp-json/ddwcpos/v1/manage-kitchen-orders',
				];					

				wp_localize_script(
					'ddwcpos-kitchen-script',
					'ddwcposKitchenObj',
					[
						'ajax'                  => [
							'ajaxUrl'   => admin_url( 'admin-ajax.php' ),
							'ajaxNonce' => wp_create_nonce( 'ddwcpos-nonce' ),
						],
						'ddwcpos_configuration' => $ddwcpos_configuration,
						'API'                   => $api,
					]
				);
			}

			// global $ddwcrc_configuration;
			// $url = "//challenges.cloudflare.com/turnstile/v0/api.js";

			// $url = add_query_arg( [
			//     'onload' => 'ddwcrcOnloadTurnstileCallback',
			//     'render' => 'explicit',
			// ], $url );

			// wp_enqueue_script( 'cloudflare-captcha', $url, [ 'ddwcrc2-front-script' ], DDWCRC_SCRIPT_VERSION );

			// wp_enqueue_script( 'ddwcrc2-front-script', DDWCRC_PLUGIN_URL . 'assets/js/front.js', [], DDWCRC_SCRIPT_VERSION );

			// wp_localize_script(
			// 	'ddwcrc2-front-script',
			// 	'ddwcrcFrontObject',
			// 	[
			// 		'ajax' => [
			// 			'ajaxUrl'   => admin_url( 'admin-ajax.php' ),
			// 			'ajaxNonce' => wp_create_nonce( 'ddwcrc-nonce' ),
			// 		],
			// 		'ddwcrc_configuration' => $ddwcrc_configuration,
			// 	]
			// );
		}

		/**
		 * Deregister front scripts function
		 *
		 * @return void
		 */
		public function ddwcpos_deregister_front_scripts() {
			global $wp;
			if ( array_key_exists( $this->ddwcpos_configuration[ 'endpoint' ], $wp->query_vars ) || array_key_exists( $this->ddwcpos_configuration[ 'kitchen_endpoint' ], $wp->query_vars ) ) {
				global $wp_styles, $wp_scripts;
				$styles = apply_filters( 'ddwcpos_modify_css_handles', [ 'ddwcpos-login-style', 'ddwcpos-pos-style', 'ddwcpos-variables-style', 'ddwcpos-kitchen-style' ] );
				foreach ( $wp_styles->queue as $s ) {
					if ( ! in_array( $s, $styles, true ) && ! empty( $wp_styles->registered[ $s ] ) ) {
						wp_dequeue_style( $wp_styles->registered[$s]->handle );
						wp_deregister_style( $wp_styles->registered[$s]->handle );
					}
				}

				$scripts = apply_filters( 'ddwcpos_modify_js_handles', [ 'ddwcpos-login-script', 'ddwcpos-pos-script', 'ddwcpos-kitchen-script' ] );
				foreach ( $wp_scripts->queue as $s ) {
					if ( ! in_array( $s, $scripts, true ) && ! empty( $wp_scripts->registered[ $s ] ) ) {
						wp_dequeue_script( $wp_scripts->registered[$s]->handle );
						wp_deregister_script( $wp_scripts->registered[$s]->handle );
					}
				}
			}
		}
	}
}
