<?php
/**
 * Layout Configuration template class
 *
 * @package MultiPOS - Point of Sale for WooCommerce
 * @version 1.0.0
 */

namespace DDWCMultiPOS\Templates\Admin\Configuration;

use DDWCMultiPOS\Helper\File\DDWCPOS_File_Create_Helper;

defined( 'ABSPATH' ) || exit();

if ( ! class_exists( 'DDWCPOS_Layout_Configuration_Template' ) ) {
	/**
	 * Layout Configuration template class
	 */
	class DDWCPOS_Layout_Configuration_Template {
		/**
		 * Construct
		 */
		public function __construct( $ddwcpos_configuration ) {
			?>
			<div class="wrap">
				<hr class="wp-header-end" />
				<?php settings_errors(); ?>
				<div class="ddwcpos-configuration-container ddwcpos-padding-top-bottom-0">
					<form action="options.php" method="POST" id="ddwcpos-general-form">
						<?php settings_fields( 'ddwcpos-layout-configuration-fields' ); ?>
						<h2 class="wp-heading-inline"><?php esc_html_e( 'Layout Configuration', 'ddwc-multipos' ); ?></h1>
						<table class="form-table">
							<tbody>
								<?php
								ddwcpos_form_field( [
									'type'           => 'color',
									'label'          => esc_html__( 'Gradient Primary Color', 'ddwc-multipos' ),
									'help_tip'       => esc_html__( 'This is the primary color used for the gradient in the POS.', 'ddwc-multipos' ),
									'description'    => esc_html__( 'Select the primary color.', 'ddwc-multipos' ),
									'id'             => 'ddwcpos-layout-primary-color',
									'value'          => $ddwcpos_configuration[ 'layout_primary_color' ],
								] );
								ddwcpos_form_field( [
									'type'           => 'color',
									'label'          => esc_html__( 'Gradient Secondary Color', 'ddwc-multipos' ),
									'help_tip'       => esc_html__( 'This is the secondary color used for the gradient in the POS.', 'ddwc-multipos' ),
									'description'    => esc_html__( 'Select the secondary color.', 'ddwc-multipos' ),
									'id'             => 'ddwcpos-layout-secondary-color',
									'value'          => $ddwcpos_configuration[ 'layout_secondary_color' ],
								] );
								ddwcpos_form_field( [
									'type'           => 'number',
									'label'          => esc_html__( 'Font Size (in px)', 'ddwc-multipos' ),
									'help_tip'       => esc_html__( 'This is the font size used in the POS', 'ddwc-multipos' ),
									'description'    => esc_html__( 'Enter the font size.', 'ddwc-multipos' ),
									'id'             => 'ddwcpos-layout-font-size',
									'value'          => $ddwcpos_configuration[ 'layout_font_size' ],
								] );
								ddwcpos_form_field( [
									'type'        => 'select',
									'label'       => esc_html__( 'Product Layout', 'ddwc-multipos' ),
									'help_tip'    => esc_html__( 'You can select the product layout you want for the POS from the given options.', 'ddwc-multipos' ),
									'description' => esc_html__( 'Choose the product layout for the POS view.', 'ddwc-multipos' ),
									'options'     => [
										'image_left' => esc_html__( 'Image on Left and Details on Right', 'ddwc-multipos' ),
										'image_top'  => esc_html__( 'Image on Top and Details on Bottom', 'ddwc-multipos' ),
									],
									'id'          => 'ddwcpos-product-layout',
									'value'       => $ddwcpos_configuration[ 'product_layout' ],
									'input_class' => [ 'ddwcpos-select2' ],
								] );
								ddwcpos_form_field( [
									'type'        => 'select',
									'label'       => esc_html__( 'Product Variation Selection Layout', 'ddwc-multipos' ),
									'help_tip'    => esc_html__( 'You can select the product variation selection layout you want for the POS from the given options.', 'ddwc-multipos' ),
									'description' => esc_html__( 'Choose the product variation selection layout for the POS view.', 'ddwc-multipos' ),
									'options'     => [
										'grid'  => esc_html__( 'Grid', 'ddwc-multipos' ),
										'popup' => esc_html__( 'Popup', 'ddwc-multipos' ),
									],
									'id'          => 'ddwcpos-product-variation-layout',
									'value'       => $ddwcpos_configuration[ 'product_variation_layout' ],
									'input_class' => [ 'ddwcpos-select2' ],
								] );
								ddwcpos_form_field( [
									'type'           => 'checkbox',
									'label'          => esc_html__( 'Enable/Disable', 'ddwc-multipos' ),
									'checkbox_label' => esc_html__( 'Show Variations as Different Products', 'ddwc-multipos' ),
									'help_tip'       => esc_html__( 'Enable/Disable show variations as different products.', 'ddwc-multipos' ),
									'description'    => esc_html__( 'If disabled, then a popup will appear to select variations for variable products.', 'ddwc-multipos' ),
									'id'             => 'ddwcpos-variation-product-enabled',
									'value'          => $ddwcpos_configuration[ 'variation_product_enabled' ],
								] );
								ddwcpos_form_field( [
									'type'           => 'checkbox',
									'label'          => esc_html__( 'Enable/Disable', 'ddwc-multipos' ),
									'checkbox_label' => esc_html__( 'Show Product Stock Value', 'ddwc-multipos' ),
									'help_tip'       => esc_html__( 'Enable/Disable to show the stock status of all products.', 'ddwc-multipos' ),
									'description'    => esc_html__( 'Choose to show stock status of products.', 'ddwc-multipos' ),
									'id'             => 'ddwcpos-show-product-stock-enabled',
									'value'          => $ddwcpos_configuration[ 'show_product_stock_enabled' ],
								] );
								?>
							</tbody>
						</table>
						<p class="description">
							<i>
								<?php
								echo sprintf( esc_html__( 'If you really like our plugin, please leave us a %s rating, we\'ll really appreciate it.', 'ddwc-multipos' ), '<a href="//codecanyon.net/downloads" target="_blank" title="' . esc_attr__( 'Review', 'ddwc-multipos' ) . '" aria-label="' . esc_attr__( 'Review', 'ddwc-multipos' ) . '"><svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 192 32" height="10"><path d="M16 26.534L6.111 32 8 20.422l-8-8.2 11.056-1.688L16 0l4.944 10.534L32 12.223l-8 8.2L25.889 32zm40 0L46.111 32 48 20.422l-8-8.2 11.056-1.688L56 0l4.944 10.534L72 12.223l-8 8.2L65.889 32zm40 0L86.111 32 88 20.422l-8-8.2 11.056-1.688L96 0l4.944 10.534L112 12.223l-8 8.2L105.889 32zm40 0L126.111 32 128 20.422l-8-8.2 11.056-1.688L136 0l4.944 10.534L152 12.223l-8 8.2L145.889 32zm40 0L166.111 32 168 20.422l-8-8.2 11.056-1.688L176 0l4.944 10.534L192 12.223l-8 8.2L185.889 32z" fill="#F5A623" fill-rule="evenodd"/></svg></a>' )
								?>
							</i>
						</p>
						<?php submit_button( esc_html__( 'Save Changes', 'ddwc-multipos' ) ); ?>
					</form>
				</div>
			</div>
			<?php
		}
	}
}
